@@ -239,6 +239,14 @@ fr_command_cfile_add (FrCommand  *comm,
 		fr_process_end_command (comm->process);
 		compressed_filename = g_strconcat (filename, ".gz", NULL);
 	}
+	else if (_g_mime_type_matches (archive->mime_type, "application/x-brotli")) {
+		fr_process_begin_command (comm->process, "brotli");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "--");
+		fr_process_add_arg (comm->process, filename);
+		fr_process_end_command (comm->process);
+		compressed_filename = g_strconcat (filename, ".br", NULL);
+	}
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip")) {
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_set_working_dir (comm->process, temp_dir);
@@ -391,6 +399,14 @@ fr_command_cfile_extract (FrCommand  *comm,
 		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
 	}
+	else if (_g_mime_type_matches (archive->mime_type, "application/x-brotli")) {
+		fr_process_begin_command (comm->process, "brotli");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-d");
+		fr_process_add_arg (comm->process, temp_file);
+		fr_process_end_command (comm->process);
+	}
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip")) {
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_set_working_dir (comm->process, temp_dir);
@@ -496,6 +512,7 @@ fr_command_cfile_extract (FrCommand  *comm,
 
 
 const char *cfile_mime_type[] = { "application/x-gzip",
+				  "application/x-brotli",
 				  "application/x-bzip",
 				  "application/x-compress",
 				  "application/x-lz4",
@@ -526,6 +543,10 @@ fr_command_cfile_get_capabilities (FrArchive  *archive,
 		if (_g_program_is_available ("gzip", check_command))
 			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
 	}
+	else if (_g_mime_type_matches (mime_type, "application/x-brotli")) {
+		if (_g_program_is_available ("brotli", check_command))
+			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
+	}
 	else if (_g_mime_type_matches (mime_type, "application/x-bzip")) {
 		if (_g_program_is_available ("bzip2", check_command))
 			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
@@ -571,6 +592,8 @@ fr_command_cfile_get_packages (FrArchive  *archive,
 {
 	if (_g_mime_type_matches (mime_type, "application/x-gzip"))
 		return PACKAGES ("gzip");
+	else if (_g_mime_type_matches (mime_type, "application/x-brotli"))
+		return PACKAGES ("brotli");
 	else if (_g_mime_type_matches (mime_type, "application/x-bzip"))
 		return PACKAGES ("bzip2");
 	else if (_g_mime_type_matches (mime_type, "application/x-compress"))
